export interface CustomerNewTicketPageConfig {
  title: string;
  categoryLabel: string;
  subjectLabel: string;
  descriptionLabel: string;
  submitButtonText: string;
  sidebarTitle: string;
  sidebarTips: {title: string; content: string}[];
}
